Python: package xml.sax

xml.sax | index /usr/local/Cellar/python/2.7.10_2/Frameworks/Python.framework/Versions/2.7/lib/python2.7/xml/sax/__init__.py Module Docs

`Simple API for XML (SAX) implementation for Python.
This module provides an implementation of the SAX 2 interface;
information about the Java version of the interface can be found at
http://www.megginson.com/SAX/. The Python version of the interface is
documented at <...>.
This package contains the following modules:
handler -- Base classes and constants which define the SAX 2 API for
the 'client-side' of SAX for Python.
saxutils -- Implementation of the convenience classes commonly used to
work with SAX.
xmlreader -- Base classes and constants which define the SAX 2 API for
the parsers used with SAX for Python.
expatreader -- Driver that allows use of the Expat parser with SAX.`

Package Contents
`` |  |
_exceptions expatreader | handler saxutils | xmlreader |

Functions
`` |  | make_parser(parser_list=[]) `Creates and returns a SAX parser. Creates the first parser it is able to instantiate of the ones given in the list created by doing parser_list + default_parser_list. The lists must contain the names of Python modules containing both a SAX parser and a create_parser function.` parse(source, handler, errorHandler=<xml.sax.handler.ErrorHandler instance>) parseString(string, handler, errorHandler=<xml.sax.handler.ErrorHandler instance>)

Data
`` |  | default_parser_list = ['xml.sax.expatreader']